@@ -27,7 +27,6 @@
 #include <qdialog.h>
 #include <qinputdialog.h>
 #include <KIO/StoredTransferJob>
-#include <KJobUiDelegate>
 #include <KJobWidgets>
 #include <kactioncollection.h>
 #include <kcodecs.h>
@@ -47,7 +46,6 @@
 
 #include <QCheckBox>
 #include <QClipboard>
-#include <QDebug>
 #include <QDomDocument>
 #include <QDomElement>
 #include <QDomNode>
@@ -56,7 +54,6 @@
 #include <QPushButton>
 #include <QStack>
 #include <QSet>
-#include <QTextStream>
 #include <QTimer>
 #include <QToolButton>
 #include <QVBoxLayout>
@@ -65,37 +62,37 @@
 #include <assert.h>
 #include <stdlib.h>
 
-QAction *KWalletEditor::_newFolderAction = 0;
-QAction *KWalletEditor::_deleteFolderAction = 0;
-QAction *KWalletEditor::_exportAction = 0;
-QAction *KWalletEditor::_mergeAction = 0;
-QAction *KWalletEditor::_importAction = 0;
-QAction *KWalletEditor::_newEntryAction = 0;
-QAction *KWalletEditor::_renameEntryAction = 0;
-QAction *KWalletEditor::_deleteEntryAction = 0;
-QAction *KWalletEditor::_copyPassAction = 0;
-QAction *KWalletEditor::_alwaysShowContentsAction = 0;
-QAction *KWalletEditor::_alwaysHideContentsAction = 0;
+QAction *KWalletEditor::_newFolderAction = nullptr;
+QAction *KWalletEditor::_deleteFolderAction = nullptr;
+QAction *KWalletEditor::_exportAction = nullptr;
+QAction *KWalletEditor::_mergeAction = nullptr;
+QAction *KWalletEditor::_importAction = nullptr;
+QAction *KWalletEditor::_newEntryAction = nullptr;
+QAction *KWalletEditor::_renameEntryAction = nullptr;
+QAction *KWalletEditor::_deleteEntryAction = nullptr;
+QAction *KWalletEditor::_copyPassAction = nullptr;
+QAction *KWalletEditor::_alwaysShowContentsAction = nullptr;
+QAction *KWalletEditor::_alwaysHideContentsAction = nullptr;
 
 RegisterCreateActionsMethod KWalletEditor::_registerCreateActionMethod(&KWalletEditor::createActions);
 
-KWalletEditor::KWalletEditor(QWidget *parent, const char *name)
-    : QWidget(parent), _displayedItem(0), _actionCollection(0), _alwaysShowContents(false)
+KWalletEditor::KWalletEditor(QWidget *parent, const QString &name)
+    : QWidget(parent), _displayedItem(nullptr), _actionCollection(nullptr), _alwaysShowContents(false)
 {
     setupUi(this);
-    setObjectName(QLatin1String(name));
+    setObjectName(name);
     _newWallet = false;
     _splitter->setStretchFactor(0, 1);
     _splitter->setStretchFactor(1, 2);
     _contextMenu = new QMenu(this);
 
-    _undoChanges->setIcon(QIcon::fromTheme(QLatin1String("edit-undo")));
-    _saveChanges->setIcon(QIcon::fromTheme(QLatin1String("document-save")));
+    _undoChanges->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
+    _saveChanges->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
     _hasUnsavedChanges = false;
 
     QVBoxLayout *box = new QVBoxLayout(_entryListFrame);
     box->setMargin(0);
-    _entryList = new KWalletEntryList(_entryListFrame, "Wallet Entry List");
+    _entryList = new KWalletEntryList(_entryListFrame, QStringLiteral("Wallet Entry List"));
     _entryList->setContextMenuPolicy(Qt::CustomContextMenu);
     _searchLine = new KTreeWidgetSearchLine(_entryListFrame, _entryList);
     _searchLine->setPlaceholderText(i18n("Search"));
@@ -156,17 +153,17 @@ KWalletEditor::~KWalletEditor()
     cg.sync();
 
     delete _w;
-    _w = 0L;
+    _w = nullptr;
     if (_nonLocal) {
         KWallet::Wallet::closeWallet(_walletName, true);
     }
     delete _contextMenu;
-    _contextMenu = NULL;
+    _contextMenu = nullptr;
 }
 
 void KWalletEditor::setWallet(KWallet::Wallet *wallet, bool isPath)
 {
-    Q_ASSERT(wallet != 0);
+    Q_ASSERT(wallet != nullptr);
     _walletName = wallet->walletName();
     _nonLocal = isPath;
 
@@ -189,9 +186,14 @@ void KWalletEditor::setWallet(KWallet::Wallet *wallet, bool isPath)
     _searchLine->setFocus();
 }
 
+bool KWalletEditor::isOpen() const
+{
+    return _w != nullptr;
+}
+
 KActionCollection *KWalletEditor::actionCollection()
 {
-    if (_actionCollection == 0) {
+    if (!_actionCollection) {
         _actionCollection = new KActionCollection(this);
     }
     return _actionCollection;
@@ -199,121 +201,121 @@ KActionCollection *KWalletEditor::actionCollection()
 
 void KWalletEditor::createActions(KActionCollection *actionCollection)
 {
-    _newFolderAction = actionCollection->addAction(QLatin1String("create_folder"));
+    _newFolderAction = actionCollection->addAction(QStringLiteral("create_folder"));
     _newFolderAction->setText(i18n("&New Folder..."));
-    _newFolderAction->setIcon(QIcon::fromTheme(QLatin1String("folder-new")));
+    _newFolderAction->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
 
-    _deleteFolderAction = actionCollection->addAction(QLatin1String("delete_folder"));
+    _deleteFolderAction = actionCollection->addAction(QStringLiteral("delete_folder"));
     _deleteFolderAction->setText(i18n("&Delete Folder"));
 
-    _mergeAction = actionCollection->addAction(QLatin1String("wallet_merge"));
+    _mergeAction = actionCollection->addAction(QStringLiteral("wallet_merge"));
     _mergeAction->setText(i18n("&Import a wallet..."));
 
-    _importAction = actionCollection->addAction(QLatin1String("wallet_import"));
+    _importAction = actionCollection->addAction(QStringLiteral("wallet_import"));
     _importAction->setText(i18n("&Import XML..."));
 
-    _exportAction = actionCollection->addAction(QLatin1String("wallet_export"));
+    _exportAction = actionCollection->addAction(QStringLiteral("wallet_export"));
     _exportAction->setText(i18n("&Export as XML..."));
 
-    _copyPassAction = actionCollection->addAction(QLatin1String("copy_action"));
+    _copyPassAction = actionCollection->addAction(QStringLiteral("copy_action"));
     _copyPassAction->setText(i18n("&Copy"));
     actionCollection->setDefaultShortcut(_copyPassAction, Qt::Key_C + Qt::CTRL);
     _copyPassAction->setEnabled(false);
 
-    _newEntryAction = actionCollection->addAction(QLatin1String("new_entry"));
+    _newEntryAction = actionCollection->addAction(QStringLiteral("new_entry"));
     _newEntryAction->setText(i18n("&New..."));
     actionCollection->setDefaultShortcut(_newEntryAction, Qt::Key_Insert);
     _newEntryAction->setEnabled(false);
 
-    _renameEntryAction = actionCollection->addAction(QLatin1String("rename_entry"));
+    _renameEntryAction = actionCollection->addAction(QStringLiteral("rename_entry"));
     _renameEntryAction->setText(i18n("&Rename"));
     actionCollection->setDefaultShortcut(_renameEntryAction, Qt::Key_F2);
     _renameEntryAction->setEnabled(false);
 
-    _deleteEntryAction = actionCollection->addAction(QLatin1String("delete_entry"));
+    _deleteEntryAction = actionCollection->addAction(QStringLiteral("delete_entry"));
     _deleteEntryAction->setText(i18n("&Delete"));
     actionCollection->setDefaultShortcut(_deleteEntryAction, Qt::Key_Delete);
     _deleteEntryAction->setEnabled(false);
 
-    _alwaysShowContentsAction = actionCollection->addAction(QLatin1String("always_show_contents"));
+    _alwaysShowContentsAction = actionCollection->addAction(QStringLiteral("always_show_contents"));
     _alwaysShowContentsAction->setText(i18n("Always show contents"));
     _alwaysShowContentsAction->setCheckable(true);
 
-    _alwaysHideContentsAction = actionCollection->addAction(QLatin1String("always_hide_contents"));
+    _alwaysHideContentsAction = actionCollection->addAction(QStringLiteral("always_hide_contents"));
     _alwaysHideContentsAction->setText(i18n("Always hide contents"));
     _alwaysHideContentsAction->setCheckable(true);
 }
 
 void KWalletEditor::connectActions()
 {
-    connect(_newFolderAction, SIGNAL(triggered(bool)), SLOT(createFolder()));
-    connect(this, SIGNAL(enableFolderActions(bool)), _newFolderAction, SLOT(setEnabled(bool)));
+    connect(_newFolderAction, &QAction::triggered, this, &KWalletEditor::createFolder);
+    connect(this, &KWalletEditor::enableFolderActions, _newFolderAction, &QAction::setEnabled);
 
     connect(_deleteFolderAction, SIGNAL(triggered(bool)), SLOT(deleteFolder()));
-    connect(this, SIGNAL(enableContextFolderActions(bool)), _deleteFolderAction, SLOT(setEnabled(bool)));
-    connect(this, SIGNAL(enableFolderActions(bool)), _deleteFolderAction, SLOT(setEnabled(bool)));
+    connect(this, &KWalletEditor::enableContextFolderActions, _deleteFolderAction, &QAction::setEnabled);
+    connect(this, &KWalletEditor::enableFolderActions, _deleteFolderAction, &QAction::setEnabled);
 
-    connect(_mergeAction, SIGNAL(triggered(bool)), SLOT(importWallet()));
-    connect(this, SIGNAL(enableWalletActions(bool)), _mergeAction, SLOT(setEnabled(bool)));
+    connect(_mergeAction, &QAction::triggered, this, &KWalletEditor::importWallet);
+    connect(this, &KWalletEditor::enableWalletActions, _mergeAction, &QAction::setEnabled);
 
-    connect(_importAction, SIGNAL(triggered(bool)), SLOT(importXML()));
-    connect(this, SIGNAL(enableWalletActions(bool)), _importAction, SLOT(setEnabled(bool)));
+    connect(_importAction, &QAction::triggered, this, &KWalletEditor::importXML);
+    connect(this, &KWalletEditor::enableWalletActions, _importAction, &QAction::setEnabled);
 
-    connect(_exportAction, SIGNAL(triggered(bool)), SLOT(exportXML()));
-    connect(this, SIGNAL(enableWalletActions(bool)), _exportAction, SLOT(setEnabled(bool)));
+    connect(_exportAction, &QAction::triggered, this, &KWalletEditor::exportXML);
+    connect(this, &KWalletEditor::enableWalletActions, _exportAction, &QAction::setEnabled);
 
-    connect(_newEntryAction, SIGNAL(triggered(bool)), SLOT(newEntry()));
+    connect(_newEntryAction, &QAction::triggered, this, &KWalletEditor::newEntry);
 
-    connect(_renameEntryAction, SIGNAL(triggered(bool)), SLOT(renameEntry()));
+    connect(_renameEntryAction, &QAction::triggered, this, &KWalletEditor::renameEntry);
 
-    connect(_deleteEntryAction, SIGNAL(triggered(bool)), SLOT(deleteEntry()));
+    connect(_deleteEntryAction, &QAction::triggered, this, &KWalletEditor::deleteEntry);
 
-    connect(_copyPassAction, SIGNAL(triggered(bool)), SLOT(copyPassword()));
-    connect(this, SIGNAL(enableWalletActions(bool)), _copyPassAction, SLOT(setEnabled(bool)));
+    connect(_copyPassAction, &QAction::triggered, this, &KWalletEditor::copyPassword);
+    connect(this, &KWalletEditor::enableWalletActions, _copyPassAction, &QAction::setEnabled);
 
     _showContents->addAction(_alwaysShowContentsAction);
     _alwaysShowContentsAction->setChecked(_alwaysShowContents);
-    connect(_alwaysShowContentsAction, SIGNAL(triggered(bool)), SLOT(onAlwaysShowContents(bool)));
+    connect(_alwaysShowContentsAction, &QAction::triggered, this, &KWalletEditor::onAlwaysShowContents);
 
     _hideContents->addAction(_alwaysHideContentsAction);
     _alwaysHideContentsAction->setChecked(!_alwaysShowContents);
-    connect(_alwaysHideContentsAction, SIGNAL(triggered(bool)), SLOT(onAlwaysHideContents(bool)));
+    connect(_alwaysHideContentsAction, &QAction::triggered, this, &KWalletEditor::onAlwaysHideContents);
 }
 
 void KWalletEditor::disconnectActions()
 {
-    disconnect(_newFolderAction, SIGNAL(triggered(bool)), this, SLOT(createFolder()));
-    disconnect(this, SIGNAL(enableFolderActions(bool)), _newFolderAction, SLOT(setEnabled(bool)));
+    disconnect(_newFolderAction, &QAction::triggered, this, &KWalletEditor::createFolder);
+    disconnect(this, &KWalletEditor::enableFolderActions, _newFolderAction, &QAction::setEnabled);
 
-    disconnect(_deleteFolderAction, SIGNAL(triggered(bool)), this, SLOT(deleteFolder()));
-    disconnect(this, SIGNAL(enableContextFolderActions(bool)), _deleteFolderAction, SLOT(setEnabled(bool)));
-    disconnect(this, SIGNAL(enableFolderActions(bool)), _deleteFolderAction, SLOT(setEnabled(bool)));
+    disconnect(_deleteFolderAction, &QAction::triggered, this, &KWalletEditor::deleteFolder);
+    disconnect(this, &KWalletEditor::enableContextFolderActions, _deleteFolderAction, &QAction::setEnabled);
+    disconnect(this, &KWalletEditor::enableFolderActions, _deleteFolderAction, &QAction::setEnabled);
 
-    disconnect(_mergeAction, SIGNAL(triggered(bool)), this, SLOT(importWallet()));
-    disconnect(this, SIGNAL(enableWalletActions(bool)), _mergeAction, SLOT(setEnabled(bool)));
+    disconnect(_mergeAction, &QAction::triggered, this, &KWalletEditor::importWallet);
+    disconnect(this, &KWalletEditor::enableWalletActions, _mergeAction, &QAction::setEnabled);
 
-    disconnect(_importAction, SIGNAL(triggered(bool)), this, SLOT(importXML()));
-    disconnect(this, SIGNAL(enableWalletActions(bool)), _importAction, SLOT(setEnabled(bool)));
+    disconnect(_importAction, &QAction::triggered, this, &KWalletEditor::importXML);
+    disconnect(this, &KWalletEditor::enableWalletActions, _importAction, &QAction::setEnabled);
 
-    disconnect(_exportAction, SIGNAL(triggered(bool)), this, SLOT(exportXML()));
-    disconnect(this, SIGNAL(enableWalletActions(bool)), _exportAction, SLOT(setEnabled(bool)));
+    disconnect(_exportAction, &QAction::triggered, this, &KWalletEditor::exportXML);
+    disconnect(this, &KWalletEditor::enableWalletActions, _exportAction, &QAction::setEnabled);
 
-    disconnect(_newEntryAction, SIGNAL(triggered(bool)), this, SLOT(newEntry()));
+    disconnect(_newEntryAction, &QAction::triggered, this, &KWalletEditor::newEntry);
 
-    disconnect(_renameEntryAction, SIGNAL(triggered(bool)), this, SLOT(renameEntry()));
+    disconnect(_renameEntryAction, &QAction::triggered, this, &KWalletEditor::renameEntry);
 
-    disconnect(_deleteEntryAction, SIGNAL(triggered(bool)), this, SLOT(deleteEntry()));
+    disconnect(_deleteEntryAction, &QAction::triggered, this, &KWalletEditor::deleteEntry);
 
-    disconnect(_copyPassAction, SIGNAL(triggered(bool)), this, SLOT(copyPassword()));
-    disconnect(this, SIGNAL(enableWalletActions(bool)), _copyPassAction, SLOT(setEnabled(bool)));
+    disconnect(_copyPassAction, &QAction::triggered, this, &KWalletEditor::copyPassword);
+    disconnect(this, &KWalletEditor::enableWalletActions, _copyPassAction, &QAction::setEnabled);
 
-    disconnect(_alwaysShowContentsAction, SIGNAL(triggered(bool)), this, SLOT(onAlwaysShowContents(bool)));
-    disconnect(_alwaysHideContentsAction, SIGNAL(triggered(bool)), this, SLOT(onAlwaysHideContents(bool)));
+    disconnect(_alwaysShowContentsAction, &QAction::triggered, this, &KWalletEditor::onAlwaysShowContents);
+    disconnect(_alwaysHideContentsAction, &QAction::triggered, this, &KWalletEditor::onAlwaysHideContents);
 }
 
 void KWalletEditor::walletClosed()
 {
-    _w = 0L;
+    _w = nullptr;
     setEnabled(false);
     emit enableWalletActions(false);
     emit enableFolderActions(false);
@@ -494,8 +496,8 @@ void KWalletEditor::entrySelectionChanged(QTreeWidgetItem *item)
         }
     }
 
-    KWalletContainerItem *ci = 0L;
-    KWalletFolderItem *fi = 0L;
+    KWalletContainerItem *ci = nullptr;
+    KWalletFolderItem *fi = nullptr;
 
     // clear the context menu
     _contextMenu->clear();
@@ -547,7 +549,7 @@ void KWalletEditor::entrySelectionChanged(QTreeWidgetItem *item)
                 _contextMenu->addSeparator();
                 _contextMenu->addAction(_copyPassAction);
                 if (_alwaysShowContents) {
-                    QTimer::singleShot(0, this, SLOT(showPasswordContents()));
+                    QTimer::singleShot(0, this, &KWalletEditor::showPasswordContents);
                 }
             } else if (ci->entryType() == KWallet::Wallet::Map) {
                 _entryStack->setCurrentIndex(2);
@@ -626,7 +628,7 @@ void KWalletEditor::entrySelectionChanged(QTreeWidgetItem *item)
 
     if (fi) {
         _currentFolder = fi->name();
-        _entryTitle->setText(QString::fromLatin1("<font size=\"+1\">%1</font>").arg(fi->text(0)));
+        _entryTitle->setText(QStringLiteral("<font size=\"+1\">%1</font>").arg(fi->text(0)));
         _iconTitle->setPixmap(fi->getFolderIcon(KIconLoader::Toolbar));
     }
 
@@ -656,7 +658,7 @@ void KWalletEditor::updateEntries(const QString &folder)
         QTreeWidgetItem *twi = pi->child(i);
         if (!entries.contains(twi->text(0))) {
             if (twi == _entryList->currentItem()) {
-                entrySelectionChanged(0L);
+                entrySelectionChanged(nullptr);
             }
             trash.push(twi);
         }
@@ -666,7 +668,7 @@ void KWalletEditor::updateEntries(const QString &folder)
         QTreeWidgetItem *twi = mi->child(i);
         if (!entries.contains(twi->text(0))) {
             if (twi == _entryList->currentItem()) {
-                entrySelectionChanged(0L);
+                entrySelectionChanged(nullptr);
             }
             trash.push(twi);
         }
@@ -676,7 +678,7 @@ void KWalletEditor::updateEntries(const QString &folder)
         QTreeWidgetItem *twi = bi->child(i);
         if (!entries.contains(twi->text(0))) {
             if (twi == _entryList->currentItem()) {
-                entrySelectionChanged(0L);
+                entrySelectionChanged(nullptr);
             }
             trash.push(twi);
         }
@@ -686,7 +688,7 @@ void KWalletEditor::updateEntries(const QString &folder)
         QTreeWidgetItem *twi = ui->child(i);
         if (!entries.contains(twi->text(0))) {
             if (twi == _entryList->currentItem()) {
-                entrySelectionChanged(0L);
+                entrySelectionChanged(nullptr);
             }
             trash.push(twi);
         }
@@ -696,7 +698,7 @@ void KWalletEditor::updateEntries(const QString &folder)
     trash.clear();
 
     // Add new entries
-    for (QStringList::const_iterator i = entries.begin(); i != entries.end(); ++i) {
+    for (QStringList::const_iterator i = entries.begin(), end = entries.end(); i != end; ++i) {
         if (fi->contains(*i)) {
             continue;
         }
@@ -719,7 +721,7 @@ void KWalletEditor::updateEntries(const QString &folder)
     }
     fi->refresh();
     if (fi->name() == _currentFolder) {
-        _entryTitle->setText(QString::fromLatin1("<font size=\"+1\">%1</font>").arg(fi->text(0)));
+        _entryTitle->setText(QStringLiteral("<font size=\"+1\">%1</font>").arg(fi->text(0)));
     }
     if (!_entryList->currentItem()) {
         _entryName->clear();
@@ -826,7 +828,7 @@ void KWalletEditor::newEntry()
         _entryList->scrollToItem(ni);
 
         fi->refresh();
-        _entryTitle->setText(QString::fromLatin1("<font size=\"+1\">%1</font>").arg(fi->text(0)));
+        _entryTitle->setText(QStringLiteral("<font size=\"+1\">%1</font>").arg(fi->text(0)));
     }
 }
 
@@ -892,7 +894,7 @@ void KWalletEditor::deleteEntry()
             delete item;
             entrySelectionChanged(_entryList->currentItem());
             fi->refresh();
-            _entryTitle->setText(QString::fromLatin1("<font size=\"+1\">%1</font>").arg(fi->text(0)));
+            _entryTitle->setText(QStringLiteral("<font size=\"+1\">%1</font>").arg(fi->text(0)));
         }
     }
 }
@@ -940,7 +942,7 @@ enum MergePlan { Prompt = 0, Always = 1, Never = 2, Yes = 3, No = 4 };
 
 void KWalletEditor::importWallet()
 {
-    QUrl url = QFileDialog::getOpenFileUrl(this, QString(), QUrl(), QLatin1String("*.kwl"));
+    QUrl url = QFileDialog::getOpenFileUrl(this, QString(), QUrl(), QStringLiteral("*.kwl"));
 
     if (url.isEmpty()) {
         return;
@@ -979,7 +981,7 @@ void KWalletEditor::importWallet()
             QMap<QString, QMap<QString, QString> > map;
             QSet<QString> mergedkeys; // prevents re-merging already merged entries.
             int rc;
-            rc = w->readMapList(QLatin1String("*"), map);
+            rc = w->readMapList(QStringLiteral("*"), map);
             if (rc == 0) {
                 QMap<QString, QMap<QString, QString> >::ConstIterator me;
                 for (me = map.constBegin(); me != map.constEnd(); ++me) {
@@ -1010,14 +1012,13 @@ void KWalletEditor::importWallet()
             }
 
             QMap<QString, QString> pwd;
-            rc = w->readPasswordList(QLatin1String("*"), pwd);
+            rc = w->readPasswordList(QStringLiteral("*"), pwd);
             if (rc == 0) {
                 QMap<QString, QString>::ConstIterator pe;
                 for (pe = pwd.constBegin(); pe != pwd.constEnd(); ++pe) {
                     bool hasEntry = _w->hasEntry(pe.key());
                     if (hasEntry && mp == Prompt) {
-                        KBetterThanKDialogBase *bd;
-                        bd = new KBetterThanKDialogBase(this);
+                        KBetterThanKDialogBase *bd = new KBetterThanKDialogBase(this);
                         bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", f->toHtmlEscaped(), pe.key().toHtmlEscaped()));
                         mp = (MergePlan)bd->exec();
                         delete bd;
@@ -1041,7 +1042,7 @@ void KWalletEditor::importWallet()
             }
 
             QMap<QString, QByteArray> ent;
-            rc = w->readEntryList(QLatin1String("*"), ent);
+            rc = w->readEntryList(QStringLiteral("*"), ent);
             if (rc == 0) {
                 QMap<QString, QByteArray>::ConstIterator ee;
                 for (ee = ent.constBegin(); ee != ent.constEnd(); ++ee) {
@@ -1051,8 +1052,7 @@ void KWalletEditor::importWallet()
                     }
                     bool hasEntry = _w->hasEntry(ee.key());
                     if (hasEntry && mp == Prompt) {
-                        KBetterThanKDialogBase *bd;
-                        bd = new KBetterThanKDialogBase(this);
+                        KBetterThanKDialogBase *bd = new KBetterThanKDialogBase(this);
                         bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", f->toHtmlEscaped(), ee.key().toHtmlEscaped()));
                         mp = (MergePlan)bd->exec();
                         delete bd;
@@ -1084,7 +1084,7 @@ void KWalletEditor::importWallet()
 
 void KWalletEditor::importXML()
 {
-    QUrl url = QFileDialog::getOpenFileUrl(this, QString(), QUrl(), QLatin1String("*.xml"));
+    const QUrl url = QFileDialog::getOpenFileUrl(this, QString(), QUrl(), QStringLiteral("*.xml"));
 
     if (url.isEmpty()) {
         return;
@@ -1118,7 +1118,7 @@ void KWalletEditor::importXML()
             continue;
         }
 
-        QString fname = e.attribute(QLatin1String("name"));
+        QString fname = e.attribute(QStringLiteral("name"));
         if (fname.isEmpty()) {
             n = n.nextSibling();
             continue;
@@ -1131,11 +1131,10 @@ void KWalletEditor::importXML()
         while (!enode.isNull()) {
             e = enode.toElement();
             QString type = e.tagName().toLower();
-            QString ename = e.attribute(QLatin1String("name"));
+            QString ename = e.attribute(QStringLiteral("name"));
             bool hasEntry = _w->hasEntry(ename);
             if (hasEntry && mp == Prompt) {
-                KBetterThanKDialogBase *bd;
-                bd = new KBetterThanKDialogBase(this);
+                KBetterThanKDialogBase *bd = new KBetterThanKDialogBase(this);
                 bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", fname.toHtmlEscaped(), ename.toHtmlEscaped()));
                 mp = (MergePlan)bd->exec();
                 delete bd;
@@ -1165,7 +1164,7 @@ void KWalletEditor::importXML()
                 while (!mapNode.isNull()) {
                     QDomElement mape = mapNode.toElement();
                     if (mape.tagName().toLower() == QLatin1String("mapentry")) {
-                        map[mape.attribute(QLatin1String("name"))] = mape.text();
+                        map[mape.attribute(QStringLiteral("name"))] = mape.text();
                     }
                     mapNode = mapNode.nextSibling();
                 }
@@ -1189,11 +1188,11 @@ void KWalletEditor::exportXML()
     xml.writeStartDocument();
     const QStringList fl = _w->folderList();
 
-    xml.writeStartElement(QLatin1String("wallet"));
-    xml.writeAttribute(QLatin1String("name"), _walletName);
+    xml.writeStartElement(QStringLiteral("wallet"));
+    xml.writeAttribute(QStringLiteral("name"), _walletName);
     for (QStringList::const_iterator i = fl.constBegin(); i != fl.constEnd(); ++i) {
-        xml.writeStartElement(QLatin1String("folder"));
-        xml.writeAttribute(QLatin1String("name"), *i);
+        xml.writeStartElement(QStringLiteral("folder"));
+        xml.writeAttribute(QStringLiteral("name"), *i);
         _w->setFolder(*i);
         QStringList entries = _w->entryList();
         for (QStringList::const_iterator j = entries.constBegin(); j != entries.constEnd(); ++j) {
@@ -1201,8 +1200,8 @@ void KWalletEditor::exportXML()
             case KWallet::Wallet::Password: {
                 QString pass;
                 if (_w->readPassword(*j, pass) == 0) {
-                    xml.writeStartElement(QLatin1String("password"));
-                    xml.writeAttribute(QLatin1String("name"), *j);
+                    xml.writeStartElement(QStringLiteral("password"));
+                    xml.writeAttribute(QStringLiteral("name"), *j);
                     xml.writeCharacters(pass);
                     xml.writeEndElement();
                 }
@@ -1211,8 +1210,8 @@ void KWalletEditor::exportXML()
             case KWallet::Wallet::Stream: {
                 QByteArray ba;
                 if (_w->readEntry(*j, ba) == 0) {
-                    xml.writeStartElement(QLatin1String("stream"));
-                    xml.writeAttribute(QLatin1String("name"), *j);
+                    xml.writeStartElement(QStringLiteral("stream"));
+                    xml.writeAttribute(QStringLiteral("name"), *j);
                     xml.writeCharacters(QLatin1String(KCodecs::base64Encode(ba)));
                     xml.writeEndElement();
                 }
@@ -1221,11 +1220,11 @@ void KWalletEditor::exportXML()
             case KWallet::Wallet::Map: {
                 QMap<QString, QString> map;
                 if (_w->readMap(*j, map) == 0) {
-                    xml.writeStartElement(QLatin1String("map"));
-                    xml.writeAttribute(QLatin1String("name"), *j);
+                    xml.writeStartElement(QStringLiteral("map"));
+                    xml.writeAttribute(QStringLiteral("name"), *j);
                     for (QMap<QString, QString>::ConstIterator k = map.constBegin(); k != map.constEnd(); ++k) {
-                        xml.writeStartElement(QLatin1String("mapentry"));
-                        xml.writeAttribute(QLatin1String("name"), k.key());
+                        xml.writeStartElement(QStringLiteral("mapentry"));
+                        xml.writeAttribute(QStringLiteral("name"), k.key());
                         xml.writeCharacters(k.value());
                         xml.writeEndElement();
                     }
@@ -1245,7 +1244,7 @@ void KWalletEditor::exportXML()
     xml.writeEndDocument();
     tf.flush();
 
-    QUrl url = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), QLatin1String("*.xml"));
+    QUrl url = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), QStringLiteral("*.xml"));
 
     if (url.isEmpty()) {
         return;
@@ -1290,7 +1289,7 @@ void KWalletEditor::onSearchTextChanged(const QString &text)
             _entryList->setCurrentItem(NULL);
             // NOTE: the 300 ms here is a value >200 ms used internally by KTreeWidgetSearchLine
             // TODO: replace this timer with a connection to KTreeWidgetSearchLine::searchUpdated signal introduced with KF5
-            QTimer::singleShot(300, _entryList, SLOT(collapseAll()));
+            QTimer::singleShot(300, _entryList, &KWalletEntryList::collapseAll);
             treeIsExpanded = false;
         }
     } else {
@@ -1300,10 +1299,10 @@ void KWalletEditor::onSearchTextChanged(const QString &text)
         }
         // NOTE: the 300 ms here is a value >200 ms used internally by KTreeWidgetSearchLine
         // TODO: replace this timer with a connection to KTreeWidgetSearchLine::searchUpdated signal introduced with KF5
-        QTimer::singleShot(300, _entryList, SLOT(selectFirstVisible()));
+        QTimer::singleShot(300, _entryList, &KWalletEntryList::selectFirstVisible);
     }
     // TODO: reduce timer count when KTreeWidgetSearchLine::searchUpdated signal will be there
-    QTimer::singleShot(300, _entryList, SLOT(refreshItemsCount()));
+    QTimer::singleShot(300, _entryList, &KWalletEntryList::refreshItemsCount);
 }
 
 void KWalletEditor::onAlwaysShowContents(bool checked)
